==> haskell-test-framework-quickcheck2-0.3.0.6-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework-quickcheck2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 test-framework-quickcheck2
version:              0.3.0.6
visibility:           public
id:                   test-framework-quickcheck2-0.3.0.6-Ge0whOeg3ODJMjJLSnhhOw
key:                  test-framework-quickcheck2-0.3.0.6-Ge0whOeg3ODJMjJLSnhhOw
license:              BSD-3-Clause
maintainer:           Andreas Abel
author:               Max Bolingbroke <batterseapower@hotmail.com>
homepage:             https://github.com/haskell/test-framework#readme
synopsis:             QuickCheck-2 support for the test-framework package.
description:
    Allows @QuickCheck-2@ properties to be used with the </package/test-framework test-framework package>.

category:             Testing
abi:                  72bda2e41debc9cc9c18acf9651fddc6
exposed:              True
exposed-modules:      Test.Framework.Providers.QuickCheck2
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/test-framework-quickcheck2-0.3.0.6

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/test-framework-quickcheck2-0.3.0.6

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/test-framework-quickcheck2-0.3.0.6

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-test-framework-quickcheck2
hs-libraries:         HStest-framework-quickcheck2-0.3.0.6-Ge0whOeg3ODJMjJLSnhhOw
depends:
    QuickCheck-2.14.3-9XJxSbkIGB4JeqA96RzyUI base-4.17.2.1
    extensible-exceptions-0.1.1.4-AGheGT2ZUDiCzp52FHEfjQ
    random-1.2.1.2-F2QY00F1ipP5r5x8nqIATJ
    test-framework-0.8.2.1-5U30u2YiZ7NrX3A73qjRi

haddock-interfaces:
    /usr/share/doc/haskell-test-framework-quickcheck2/html/test-framework-quickcheck2.haddock

haddock-html:         /usr/share/doc/haskell-test-framework-quickcheck2/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-test-framework-quickcheck2-0.3.0.6-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework-quickcheck2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 test-framework-quickcheck2
version:              0.3.0.6
visibility:           public
id:                   test-framework-quickcheck2-0.3.0.6-6QmgGQweCB4ING8Rjag6of
key:                  test-framework-quickcheck2-0.3.0.6-6QmgGQweCB4ING8Rjag6of
license:              BSD-3-Clause
maintainer:           Andreas Abel
author:               Max Bolingbroke <batterseapower@hotmail.com>
homepage:             https://github.com/haskell/test-framework#readme
synopsis:             QuickCheck-2 support for the test-framework package.
description:
    Allows @QuickCheck-2@ properties to be used with the </package/test-framework test-framework package>.

category:             Testing
abi:                  baf77f342f1872b7147b77a48fff9b2e
exposed:              True
exposed-modules:      Test.Framework.Providers.QuickCheck2
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/test-framework-quickcheck2-0.3.0.6

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/test-framework-quickcheck2-0.3.0.6

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/test-framework-quickcheck2-0.3.0.6

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-test-framework-quickcheck2
hs-libraries:         HStest-framework-quickcheck2-0.3.0.6-6QmgGQweCB4ING8Rjag6of
depends:
    QuickCheck-2.14.3-DOFi1GQ9eE04hBoMxr6sJJ base-4.17.2.1
    extensible-exceptions-0.1.1.4-AGheGT2ZUDiCzp52FHEfjQ
    random-1.2.1.2-LUVepo9xpbYCdyIKOUBgF2
    test-framework-0.8.2.1-JnA24LE0fNafbSuzA39uZ

haddock-interfaces:
    /usr/share/doc/haskell-test-framework-quickcheck2/html/test-framework-quickcheck2.haddock

haddock-html:         /usr/share/doc/haskell-test-framework-quickcheck2/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
